\ProvidesClass{AulaIFBA}[2015/07/29]

\let\@presentationArticle=0

\DeclareOption{handout}{%
  \PassOptionsToClass{handout}{beamer}  
}

\DeclareOption{article}{%	
	\let\@presentationArticle=1
}

\PassOptionsToPackage{brazilian}{translator}


\ProcessOptions

  \if\@presentationArticle0
	  \PassOptionsToPackage{aspectratio=149}{beamer}
	  \LoadClass[12pt]{beamer} 
	  \hypersetup{pdfstartview={Fit}}
  \fi

  \if\@presentationArticle1
	  \PassOptionsToClass{twoside}{article}
	  \LoadClass[12pt]{article}
	  \RequirePackage{beamerarticle}
	  \RequirePackage{fullpage}
  \fi


\RequirePackage[brazilian]{babel}
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage{amsmath}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}
\RequirePackage{tikz}
\RequirePackage{multicol}


\RequirePackage{etoolbox}
\setbeamertemplate{theorems}[numbered]
\numberwithin{subsection}{section}
\numberwithin{theorem}{subsection}
% %Modificando numeração de problema e solução para ficar independente dos outros theoremas
\undef{\problem}
\undef{\solution}
\theoremstyle{plain}
\newtheorem{problem}{\translate{Problem}}
\newtheorem{solution}{\translate{Solution}}
%\numberwithin{problem}{subsection}
%\numberwithin{solution}{subsection}
%retirando italico do corpo da solução
\let\oldsolution\solution
\renewcommand{\solution}{\oldsolution\normalfont}

\usetikzlibrary{shapes.geometric,arrows,shadows,shadows.blur,shapes,positioning}

\newcommand{\ifbalogo}[2][1]{
	\resizebox {#2} {!} {
		\begin{tikzpicture}		
			
			\tikzset{every node/.style={opacity=#1, blur shadow = {opacity=#1,shadow xshift=2ex,shadow yshift=-2ex}}}			
			
			\tikzstyle{n1} = [rectangle, rounded corners, minimum width=0.3\textwidth, minimum height=0.3\textwidth,text centered, draw=black, fill=green!30]
			\tikzstyle{n2} = [ellipse, minimum width=0.3\textwidth, minimum height=0.3\textwidth, text centered, draw=black, fill=red!30]

			\node (i0) [n2] {};
			\node (i1) [n1, right of=i0, xshift=0.3\textwidth] {};
			\node (i2) [n1, right of=i1, xshift=0.3\textwidth] {};
			
			\node (i3) [n1, below of=i0, yshift=-0.3\textwidth] {};
			\node (i4) [n1, right of=i3, xshift=0.3\textwidth] {};

			\node (i5) [n1, below of=i3, yshift=-0.3\textwidth] {};
			\node (i6) [n1, right of=i5, xshift=0.3\textwidth] {};
			\node (i7) [n1, right of=i6, xshift=0.3\textwidth] {};

			\node (i8) [n1, below of=i5, yshift=-0.3\textwidth] {};
			\node (i9) [n1, right of=i8, xshift=0.3\textwidth] {};
		\end{tikzpicture}
	}

}

\RequirePackage[alf]{abntex2cite}
\RequirePackage{caption}

\captionsetup{font=scriptsize,labelfont=scriptsize}

\setcounter{errorcontextlines}{999}

\mode<handout>
{

	\usetheme{default}
	\setbeamertemplate{navigation symbols}{} 
    \usepackage{pgf}
	\usepackage{pgfpages}
  

\pgfpagesdeclarelayout{3 on 1 with notes} {
    \edef\pgfpageoptionheight{\the\paperheight}
    \edef\pgfpageoptionwidth{\the\paperwidth}
    \edef\pgfpageoptionborder{0pt}
 }
 {
    \pgfpagesphysicalpageoptions
    {%
      logical pages=6,%
      physical height=\pgfpageoptionheight,%
      physical width=\pgfpageoptionwidth,%
%      last logical shipout=3%
      last logical shipout=3%
    }
    
        \pgfpageslogicalpageoptions{1}
        {%
                scale=.70,
                center=\pgfpoint{.25\pgfphysicalwidth}{.82\pgfphysicalheight}%
        }%
        \pgfpageslogicalpageoptions{2}
        {%
                scale=.70,
                center=\pgfpoint{.25\pgfphysicalwidth}{.50\pgfphysicalheight}%
        }%
        \pgfpageslogicalpageoptions{3}
        {%
                scale=.70,
                center=\pgfpoint{.25\pgfphysicalwidth}{.18\pgfphysicalheight}%
        }%

	
	\pgfpageslogicalpageoptions{4}
    {%
      border shrink=\pgfpageoptionborder,%
      resized width=.5\pgfphysicalwidth,%
      resized height=.5\pgfphysicalheight,%
      center=\pgfpoint{.75\pgfphysicalwidth}{.82\pgfphysicalheight},%
      copy from=4
    }%
    \pgfpageslogicalpageoptions{5}
    {%
      border shrink=\pgfpageoptionborder,%
      resized width=.5\pgfphysicalwidth,%
      resized height=.5\pgfphysicalheight,%
      center=\pgfpoint{.75\pgfphysicalwidth}{.50\pgfphysicalheight},%
      copy from=5
    }%
    \pgfpageslogicalpageoptions{6}
    {%
      border shrink=\pgfpageoptionborder,%
      resized width=.5\pgfphysicalwidth,%
      resized height=.5\pgfphysicalheight,%
      center=\pgfpoint{.75\pgfphysicalwidth}{.18\pgfphysicalheight},%
      copy from=6
    }%
    
	\AtBeginDocument{
      \newbox\notesbox
      \setbox\notesbox=\vbox{
        \hsize=\paperwidth
        \vskip-1in\hskip-1in\vbox{
          \vskip1cm
        Anotações\vskip1cm
        \hrule width\paperwidth\vskip1cm
        \hrule width\paperwidth\vskip1cm
        \hrule width\paperwidth\vskip1cm
        \hrule width\paperwidth\vskip1cm
        \hrule width\paperwidth\vskip1cm
        \hrule width\paperwidth\vskip1cm
        \hrule width\paperwidth}
      }
      \pgfpagesshipoutlogicalpage{4}\copy\notesbox
      \pgfpagesshipoutlogicalpage{5}\copy\notesbox
      \pgfpagesshipoutlogicalpage{6}\copy\notesbox
    }
 }

	\pgfpagesuselayout{3 on 1 with notes}[letterpaper,border shrink=2.5mm]
	%\pgfpagesuselayout{4 on 1}[letterpaper,landscape,border shrink=2.5mm]
	\titlegraphic{\ifbalogo{0.5in}}
  \nofiles
}
\mode<beamer|second|trans>{

	\usetheme{JuanLesPins}
	\setbeamercolor{structure}{fg=olive}
	\setbeamercovered{transparent} 
	\setbeamertemplate{navigation symbols}{} 
	\setbeamertemplate{caption}[numbered]
	\usebackgroundtemplate{
		\tikz\node{
				\vbox to \paperheight{\vfil\hbox to \paperwidth{\hfil\ifbalogo[0.1]{0.5\paperwidth}\hfil}\vfil}
		};
	}
	\logo{\ifbalogo{0.5in}} 
}

\mode<article>{
	\usepackage{tcolorbox}
	
	%\let\example\tcolorbox
	%\let\endexample\endtcolorbox
	%\newcounter{theorem}[subsection]
	\renewenvironment{example}{\stepcounter{theorem}\begin{tcolorbox}[title=\translate{Example} \arabic{section}.\arabic{subsection}.\arabic{theorem},colframe=green!25,colback=green!10,coltitle=green!20!black]}{%
	    \end{tcolorbox}\ignorespacesafterend% as suggested above
	}
	\renewenvironment{problem}{\stepcounter{problem}\begin{tcolorbox}[title=\translate{Problem} \arabic{problem},colframe=yellow!25,colback=yellow!10,coltitle=yellow!20!black]}{%
	    \end{tcolorbox}\ignorespacesafterend% as suggested above
	}
	\renewenvironment{solution}{\stepcounter{solution}\begin{tcolorbox}[title=\translate{Solution} \arabic{solution},colframe=green!25,colback=green!10,coltitle=green!20!black]}{%
	    \end{tcolorbox}\ignorespacesafterend% as suggested above
	}
	
	
	\renewenvironment{definition}{\stepcounter{theorem}\begin{tcolorbox}[title=\translate{Definition} \arabic{section}.\arabic{subsection}.\arabic{theorem},colframe=blue!25,colback=blue!10,coltitle=blue!20!black]}{%
	    \end{tcolorbox}\ignorespacesafterend% as suggested above
	}
	
	% % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
	\RequirePackage{endfloatIFBA}
	\DeclareDelayedFloat{solution}[slt]{solution}
	\renewcommand{\efloatseparator}{\mbox{}}
	\newcommand{\listofsolutions}{Lista de Soluções}	
	% % % % % % % % % % % % % % % % % % % % % % % % % % % % % %

}


\RequirePackage{amsthm}

%Elementos do Fluxograma
\tikzstyle{startstop} = [ultra thick,rectangle, rounded corners, minimum width=3cm, minimum height=1cm,text centered, draw=black, fill=red!30]
\tikzstyle{inputFlux} = [ultra thick,trapezium, trapezium left angle=70, trapezium right angle=110, minimum width=3cm, minimum height=1cm, text centered, draw=black, fill=blue!30]

\tikzstyle{outputFlux} = [ultra thick, inner xsep=10pt, minimum width=3cm, text centered, minimum height=1cm,output fill=blue!30]
\tikzset{output fill/.style={append after command={
    \pgfextra
        \draw[sharp corners, fill=#1] ([xshift=-0.3cm]\tikzlastnode.north east) -- ([xshift=0.5cm]\tikzlastnode.north west) -- (\tikzlastnode.west) -- ([xshift=0.5cm]\tikzlastnode.south west) -- ([xshift=-0.3cm]\tikzlastnode.south east) .. controls ([xshift=0.1cm]\tikzlastnode.east) .. ([xshift=-0.3cm]\tikzlastnode.north east);
    \endpgfextra}}}

\tikzstyle{process} = [ultra thick,rectangle, minimum width=3cm, minimum height=1cm, text centered, draw=black, fill=orange!30]
\tikzstyle{decision} = [ultra thick,diamond, minimum width=1cm, minimum height=1cm, text centered, draw=black, fill=green!30]
\tikzstyle{conector} = [ultra thick,ellipse, minimum width=0.3cm, minimum height=0.3cm,inner sep=0pt, draw=black, fill=black]
\tikzstyle{loop} = [ultra thick,regular polygon, regular polygon sides=6,inner sep=0pt, draw=black, inner sep=0,fill=yellow!30]
\tikzstyle{arrow} = [thick,->,>=stealth]
%FIM Elementos do Fluxograma

\RequirePackage{nameref}
\makeatletter
\newcommand*{\currentname}{\@currentlabelname}

\def\ifbafrontpage{%
	\mode<presentation>{
	 	{
	 	\usebackgroundtemplate{}
	 	\begin{frame}
	 		\maketitle
	 	\end{frame}
	 	}
	 	\begin{frame}{}
		 	\setcounter{tocdepth}{2}
	 		\tableofcontents
	 		\newpage
	 	\end{frame}
	 }
	 \mode<article>{
	
	  \thispagestyle{empty}
	  
		\begin{center}
		\ifbalogo{0.2\textwidth}

		\textbf{Instituto Federal da Bahia} \\
		\textbf{Campus Eunápolis} \\
		\vspace*{\fill}			
		{\LARGE \@title} \\
		\vspace*{\fill}			
		\vspace*{\fill}			
		Prof.: \@author \\
		\vspace*{\fill}		
		\today
		\end{center}
	  \clearpage{\pagestyle{empty}\cleardoublepage}
	  \thispagestyle{empty}
	  \tableofcontents
	  \clearpage{\pagestyle{empty}\cleardoublepage}

	 }
	 
}

\newcommand\ifbafrontpagecols[1]{%
	\mode<presentation>{
	 	{
	 	\usebackgroundtemplate{}
	 	\begin{frame}
	 		\maketitle
	 	\end{frame}
	 	}
	 	\begin{frame}{}
	 		\begin{multicols}{#1}
 			\setcounter{tocdepth}{2}
 			\tableofcontents
 			\end{multicols}
	 		\newpage
	 	\end{frame}
	 }
	 \mode<article>{
	
		\ifbafrontpage

	 }
	 
}


\makeatother
%\AtBeginSection{\begin{frame}[environment=slide,allowframebreaks]\frametitle{\currentname}}
%\AtEndSection{\end{frame}}

\newenvironment{slide}
{\begin{frame}[environment=slide,allowframebreaks]
\frametitle<presentation>{\currentname}}
{\end{frame}}

\mode<presentation>{
	\newdimen\oldtextwidth
	\newdimen\oldoddsidemargin
}

\newenvironment{clearslide}
{
	\mode<presentation>{
		\oldtextwidth\textwidth
		\oldoddsidemargin\oddsidemargin
		\setlength{\textwidth}{0.9\paperwidth}
		\setlength{\oddsidemargin}{-43pt}
		\hsize\textwidth
		\columnwidth\textwidth
	}
	\begin{frame}[plain]
	\frametitle<presentation>{\currentname}
}
{
	\end{frame}	
	\mode<presentation>{
		\setlength{\textwidth}{\oldtextwidth}
		\setlength{\oddsidemargin}{\oldoddsidemargin}
		\hsize\textwidth
		\columnwidth\textwidth
	}
}

	
\institute[IFBA]{Instituto Federal da Bahia} 

\RequirePackage{listings}
\RequirePackage{lstlinebgrd}
\RequirePackage{xcolor}
\RequirePackage{courier}
\renewcommand{\lstlistingname}{Código}
\lstset{basicstyle=\tiny\ttfamily,breaklines=true}
\lstset{frame=bottomline}
\lstset{
	language=Java,
	showstringspaces=false,
	numbers=left,
	%backgroundcolor=\color{gray!10},
	keywordstyle=\color{blue}\bfseries,
	frame=single,
	tabsize=4,
	rulecolor=\color{black!30},
	%title=\lstname,
	escapeinside={\%*}{*)},
	breakatwhitespace=true,
	%framextopmargin=1pt,
	framexbottommargin=1pt,
	inputencoding=utf8,
	extendedchars=true,
	   literate=%
	        {é}{{\'{e}}}1
	        {è}{{\`{e}}}1
	        {ê}{{\^{e}}}1
	        {ë}{{\¨{e}}}1
	        {È}{{\`{E}}}1
	        {É}{{\'{E}}}1
	        {Ê}{{\^{E}}}1
	        {û}{{\^{u}}}1
	        {ù}{{\`{u}}}1
	        {ú}{{\'{u}}}1
	        {â}{{\^{a}}}1
	        {à}{{\`{a}}}1
	        {á}{{\'{a}}}1
	        {ã}{{\~{a}}}1
	        {Á}{{\'{A}}}1
	        {Â}{{\^{A}}}1
	        {Ã}{{\~{A}}}1
	        {ç}{{\c{c}}}1
	        {Ç}{{\c{C}}}1
	        {õ}{{\~{o}}}1
	        {ó}{{\'{o}}}1
	        {ô}{{\^{o}}}1
	        {Õ}{{\~{O}}}1
	        {Ó}{{\'{O}}}1
	        {Ô}{{\^{O}}}1
	        {î}{{\^{i}}}1
	        {Î}{{\^{I}}}1
	        {í}{{\'{i}}}1
	        {Í}{{\~{Í}}}1
}

% Define Language
\lstdefinelanguage{portugol}
{
  % list of keywords
  morekeywords={
    aleatorio,
    algoritmo,
    arquivo,
    ate,
    caractere,
    caso,
    cronometro,
    debug,
    e,
    eco,
    enquanto,
    entao,
    escolha,
    escreva,
    escreval,
    faca,
    falso,
    fimalgoritmo,
    fimenquanto,
    fimescolha,
    fimfuncao,
    fimpara,
    fimprocedimento,
    fimrepita,
    fimse,
    funcao,
    inicio,
    int,
    inteiro,
    interrompa,
    leia,
    limpatela,
    logico,
    mod,
    nao,
    ou,
    outrocaso,
    para,
    passo,
    pausa, 
    real,
    procedimento,
    repita,
    retorne,
    se,
    senao,
    timer,
    var, 
    vetor,
    verdadeiro,
    xou
  },
  sensitive=false, % keywords are not case-sensitive
  morecomment=[l]{//}, % l is for line comment
  morecomment=[s]{/*}{*/}, % s is for start and end delimiter
  morestring=[b]" % defines that strings are enclosed in double quotes
}

\addtobeamertemplate{navigation symbols}{}{%
    \usebeamerfont{footline}%
    \usebeamercolor[fg]{footline}%
    \hspace{1em}%
    \insertframenumber/\inserttotalframenumber
}

%ajustando padding da tabela
\renewcommand{\arraystretch}{1.4}